# StatsTextResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**groups** | [**Groups**](Groups.md) |  | [optional] 
**text** | **str** | Describe the complete text for the text widget, after placeholders injection. | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


